@@ -129,7 +129,7 @@ void FMRadio::setActive(bool value)
                 return;
 
             newRadioTuner(); // start/stop(){} are empty methods in qtmobility
-            qDebug() << "newRadioTuner()";
+            qDebug() << "new radioTuner";
             sendStatus(2);
         }
         else
@@ -258,7 +258,7 @@ void FMRadio::startAutoScan()
 
         int sig_strength = radioTuner->signalStrength();
 
-        if(sig_strength >= 10)
+        if(sig_strength >= 31)
         {
             QString r_ps = ps();
             r_freq += 100000;
@@ -349,9 +349,9 @@ void FMRadio::radioFreqChanged(int freq)
 
 void FMRadio::processSignal(int newSignal)
 {
-    if (m_signalStrenght != newSignal*2)
+    if (m_signalStrenght != newSignal)
     {
-        m_signalStrenght = newSignal*2;
+        m_signalStrenght = newSignal;
         emit signalStrenghtChanged();
     }
 }
@@ -426,6 +426,3 @@ bool FMRadio::headphoneConnected()
         return true;
     else return false;
 }
-
-
-//http://old.radiopolska.pl/wykaz/polska.php
