@@ -3,17 +3,9 @@
 
 #include <QObject>
 #include <QtDBus>
-#include <QProcess>
-#include <QApplication>
-#include <QDesktopWidget>
 #include <QDebug>
 
 
-#include <QTextStream>
-#include <QX11Info>
-#include <X11/Xlib.h>
-#include <X11/Xatom.h>
-
 class KeypadOnHelper : public QObject
 {
     Q_OBJECT
