@@ -97,30 +97,13 @@ V4LRadioControl::V4LRadioControl(QObject *parent)
     tickTimer->setInterval(10000);
     connect(tickTimer,SIGNAL(timeout()),this,SLOT(enableFMRX()));
     tickTimer->start();
-
-    busTimer = new QTimer(this);
-    busTimer->setInterval(250);
-    connect(busTimer, SIGNAL(timeout()), this, SLOT(onBusTimer()));
-    busTimer->start();
 }
 
-void V4LRadioControl::onBusTimer()
-{
-    GstMessage *msg;
-    while ((msg = gst_bus_pop(gstbus)) != 0)
-    {
-        busCall(msg);
-        gst_message_unref(msg);
-    }
-}
 
-void V4LRadioControl::busCall(GstMessage *message)
+static gboolean busCall(GstBus *bus, GstMessage *message, gpointer object)
 {
     //qDebug() << "busCall: " << GST_MESSAGE_TYPE_NAME(message) << "| object: " << ((GST_MESSAGE_SRC(message) == GST_OBJECT(pipeline)) ? "pipeline" : ((GST_MESSAGE_SRC(message) == GST_OBJECT(sink)) ? "sink" : ((GST_MESSAGE_SRC(message) == GST_OBJECT(source)) ? "source" : "other")));
 
-    if(GST_MESSAGE_SRC(message) == GST_OBJECT(pipeline))
-    {
-
         switch GST_MESSAGE_TYPE(message) {
             case GST_MESSAGE_ERROR: {
                 GError *error;
@@ -130,14 +113,16 @@ void V4LRadioControl::busCall(GstMessage *message)
                 break;
             }
             case GST_MESSAGE_STATE_CHANGED: {
-                onStateChanged(message);
+                V4LRadioControl *v4l = static_cast<V4LRadioControl*>(object);
+                v4l->onStateChanged(message);
                 break;
             }
             default: {
                 break;
             }
         }
-    }
+
+        return true;
 }
 
 void V4LRadioControl::onStateChanged(GstMessage *message)
@@ -147,11 +132,12 @@ void V4LRadioControl::onStateChanged(GstMessage *message)
          GstState newstate, oldstate, pendingstate;
          gst_message_parse_state_changed(message, &oldstate, &newstate, &pendingstate);
 
-         qDebug() << "from: " << gst_element_state_get_name(oldstate) << "to: " << gst_element_state_get_name(newstate)  << "pending: " << gst_element_state_get_name(pendingstate);
+         //qDebug() << "from: " << gst_element_state_get_name(oldstate) << "to: " << gst_element_state_get_name(newstate)  << "pending: " << gst_element_state_get_name(pendingstate);
          if(newstate == GST_STATE_PAUSED)
          {
              if(initPipeline)
                 gst_element_set_state (pipeline, GST_STATE_PLAYING);
+
              initPipeline = false;
          } else if(newstate == GST_STATE_PLAYING) {
              allowNullState = true;
@@ -203,6 +189,7 @@ bool V4LRadioControl::createGstPipeline()
     pipeline = gst_pipeline_new("my-pipeline");
 
     gstbus = gst_pipeline_get_bus(GST_PIPELINE(pipeline));
+    gst_bus_add_watch(gstbus, busCall, this);
     gst_object_unref(gstbus);
 
     source = gst_element_factory_make ("pulsesrc", "source");
@@ -408,10 +395,13 @@ int V4LRadioControl::signalStrength() const
     if(!file.open(QIODevice::ReadOnly | QIODevice::Text))
         return 0;
     QTextStream st(&file);
-    QString rssi = st.readLine();
+    int rssi = st.readLine().toInt();
     file.close();
+    if(rssi > -80)
+        rssi = -80;
 
-    return (112+rssi.toInt());
+    return ((112+rssi)*100)/32;
+    //return (112+rssi.toInt());
 }
 
 int  V4LRadioControl::vol(snd_hctl_elem_t *elem) const
@@ -765,7 +755,7 @@ void V4LRadioControl::search()
         emit signalStrengthChanged(sig);
     }
 
-    if (signal >= 10) {
+    if (signal >= 31) {
         if(forward) {
             setFrequency(currentFreq+step);
         } else {
